Serializes the table's recorded activities as a W3C PROV-JSON document: the
table is an entity, each recorded step is an activity associated with the
krt software agent and generating the table.
Usage
as_prov_json(x, path = NULL, audience = c("author", "public"))Arguments
- x
A krt_tbl.
- path
Output path, or
NULLto return the JSON string.- audience
"author"(default) keeps provenance parameters;"public"redacts the table first, so recorded parameters that could echo sensitive input values are dropped.
Examples
cat(substr(as_prov_json(normalize_ids(krt_example)), 1, 40))
#> {
#> "prefix": {
#> "krt": "https://chox