Fields lost or folded when projecting to a profile
Source:R/profile_mapping.R
mapping_lossy_fields.RdReturns the core fields that are present in the table but are not preserved as their own column by the profile (they are either folded into a free-text catch-all column or dropped). These drive the lossy-export warning.
Arguments
- x
A krt_tbl.
- profile
A
krt_profileor profile name.